summaryrefslogtreecommitdiff
path: root/Echolot/Config.pm
diff options
context:
space:
mode:
authorPeter Palfrader <peter@palfrader.org>2003-02-17 07:22:49 +0000
committerPeter Palfrader <peter@palfrader.org>2003-02-17 07:22:49 +0000
commit2123fb6af0fa319ff43286580d035e8f986e4397 (patch)
tree4fa5c9b99c1d9c9ccb730fd9e7d8c69685a46add /Echolot/Config.pm
parent4e4b74364edea060a70bda3bacc848eb2a26dad5 (diff)
Some changes wrt what we consider for intensive care and changes to timers
Diffstat (limited to 'Echolot/Config.pm')
-rw-r--r--Echolot/Config.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/Echolot/Config.pm b/Echolot/Config.pm
index 9c7405c..4b6a6fb 100644
--- a/Echolot/Config.pm
+++ b/Echolot/Config.pm
@@ -1,7 +1,7 @@
package Echolot::Config;
# (c) 2002 Peter Palfrader <peter@palfrader.org>
-# $Id: Config.pm,v 1.56 2003/02/16 14:40:43 weasel Exp $
+# $Id: Config.pm,v 1.57 2003/02/17 07:22:49 weasel Exp $
#
=pod
@@ -101,7 +101,7 @@ sub init($) {
ping_every_nth_time => 48, # send out pings to the same remailer every 48 calls, i.e. every 4 hours
chainpinger_interval => 5*60, # send out pings every 5 minutes
- chainping_every_nth_time => 864, # send out pings to the same chain every 864 calls, i.e. every 3 days
+ chainping_every_nth_time => 2016, # send out pings to the same chain every 2016 calls, i.e. week
chainping_ic_every_nth_time => 288, # send out pings to broken or unknown chains every 288 calls, i.e. every day
chainping_period => 10*24*60*60, # 12 days
chainping_fudge => 0.3, # if less than 0.3 * rel1 * rel2 make it, the chain is really broken